# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class ExecutorClient:
    def __init__(self, transport):
        self.transport = transport

    def DescribeLanguage(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.executor.Executor/DescribeLanguage",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.executor.DescribeLanguageOutput"),
            **kwargs,
        )

    def ListLanguages(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.executor.Executor/ListLanguages",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.executor.ListLanguagesOutput"),
            **kwargs,
        )

    def DescribeRuntime(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.executor.Executor/DescribeRuntime",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.executor.DescribeRuntimeOutput"),
            **kwargs,
        )

    def ListRuntime(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.executor.Executor/ListRuntime",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.executor.ListRuntimeOutput"),
            **kwargs,
        )

    def DescribeCodeTemplate(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.executor.Executor/DescribeCodeTemplate",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.executor.DescribeCodeTemplateOutput"),
            **kwargs,
        )

