# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/quota.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/cognito/quota.proto',
  package='eolymp.cognito',
  syntax='proto3',
  serialized_options=b'Z5github.com/eolymp/contracts/go/eolymp/cognito;cognito',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/cognito/quota.proto\x12\x0e\x65olymp.cognito\")\n\x05Quota\x12\r\n\x05value\x18\x01 \x01(\x05\x12\x11\n\tunlimited\x18\x02 \x01(\x08\x42\x37Z5github.com/eolymp/contracts/go/eolymp/cognito;cognitob\x06proto3'
)




_QUOTA = _descriptor.Descriptor(
  name='Quota',
  full_name='eolymp.cognito.Quota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.cognito.Quota.value', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unlimited', full_name='eolymp.cognito.Quota.unlimited', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=87,
)

DESCRIPTOR.message_types_by_name['Quota'] = _QUOTA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Quota = _reflection.GeneratedProtocolMessageType('Quota', (_message.Message,), {
  'DESCRIPTOR' : _QUOTA,
  '__module__' : 'eolymp.cognito.quota_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.Quota)
  })
_sym_db.RegisterMessage(Quota)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
