# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/form.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/form.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17\x65olymp/judge/form.proto\x12\x0c\x65olymp.judge\"\xd0\x03\n\x04\x46orm\x12(\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x18.eolymp.judge.Form.Field\x1a\x9d\x03\n\x05\x46ield\x12\n\n\x02id\x18\x01 \x01(\t\x12\x39\n\x0b\x64\x65scription\x18\n \x03(\x0b\x32$.eolymp.judge.Form.Field.Description\x12+\n\x04type\x18\x14 \x01(\x0e\x32\x1d.eolymp.judge.Form.Field.Type\x12\x10\n\x08required\x18\x1e \x01(\x08\x12\x0e\n\x06regexp\x18\x1f \x01(\t\x12\x0b\n\x03min\x18  \x01(\x05\x12\x0b\n\x03max\x18! \x01(\x05\x12\x0f\n\x07\x63hoices\x18\" \x03(\t\x1a\\\n\x0b\x44\x65scription\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\x08\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x0c\n\x04help\x18\x04 \x01(\t\x12\x0f\n\x07\x63hoices\x18\x05 \x03(\t\"u\n\x04Type\x12\n\n\x06STRING\x10\x00\x12\x08\n\x04TEXT\x10\x01\x12\n\n\x06NUMBER\x10\x02\x12\n\n\x06\x43HOICE\x10\x03\x12\x08\n\x04\x44\x41TE\x10\x04\x12\t\n\x05\x45MAIL\x10\x05\x12\x0c\n\x08\x43HECKBOX\x10\x06\x12\x1c\n\x17UKRAINE_CITY_AND_REGION\x10\xe8\x07\"f\n\x0cRegistration\x12-\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x1f.eolymp.judge.Registration.Data\x1a\'\n\x04\x44\x61ta\x12\x10\n\x08\x66ield_id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\tB3Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
)



_FORM_FIELD_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.judge.Form.Field.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STRING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NUMBER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHOICE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMAIL', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHECKBOX', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UKRAINE_CITY_AND_REGION', index=7, number=1000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=389,
  serialized_end=506,
)
_sym_db.RegisterEnumDescriptor(_FORM_FIELD_TYPE)


_FORM_FIELD_DESCRIPTION = _descriptor.Descriptor(
  name='Description',
  full_name='eolymp.judge.Form.Field.Description',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default', full_name='eolymp.judge.Form.Field.Description.default', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locale', full_name='eolymp.judge.Form.Field.Description.locale', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='eolymp.judge.Form.Field.Description.label', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='help', full_name='eolymp.judge.Form.Field.Description.help', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choices', full_name='eolymp.judge.Form.Field.Description.choices', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=387,
)

_FORM_FIELD = _descriptor.Descriptor(
  name='Field',
  full_name='eolymp.judge.Form.Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.Form.Field.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='eolymp.judge.Form.Field.description', index=1,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.judge.Form.Field.type', index=2,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required', full_name='eolymp.judge.Form.Field.required', index=3,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regexp', full_name='eolymp.judge.Form.Field.regexp', index=4,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='eolymp.judge.Form.Field.min', index=5,
      number=32, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='eolymp.judge.Form.Field.max', index=6,
      number=33, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choices', full_name='eolymp.judge.Form.Field.choices', index=7,
      number=34, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FORM_FIELD_DESCRIPTION, ],
  enum_types=[
    _FORM_FIELD_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=506,
)

_FORM = _descriptor.Descriptor(
  name='Form',
  full_name='eolymp.judge.Form',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='eolymp.judge.Form.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FORM_FIELD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=506,
)


_REGISTRATION_DATA = _descriptor.Descriptor(
  name='Data',
  full_name='eolymp.judge.Registration.Data',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='field_id', full_name='eolymp.judge.Registration.Data.field_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.judge.Registration.Data.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=571,
  serialized_end=610,
)

_REGISTRATION = _descriptor.Descriptor(
  name='Registration',
  full_name='eolymp.judge.Registration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='eolymp.judge.Registration.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REGISTRATION_DATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=508,
  serialized_end=610,
)

_FORM_FIELD_DESCRIPTION.containing_type = _FORM_FIELD
_FORM_FIELD.fields_by_name['description'].message_type = _FORM_FIELD_DESCRIPTION
_FORM_FIELD.fields_by_name['type'].enum_type = _FORM_FIELD_TYPE
_FORM_FIELD.containing_type = _FORM
_FORM_FIELD_TYPE.containing_type = _FORM_FIELD
_FORM.fields_by_name['fields'].message_type = _FORM_FIELD
_REGISTRATION_DATA.containing_type = _REGISTRATION
_REGISTRATION.fields_by_name['data'].message_type = _REGISTRATION_DATA
DESCRIPTOR.message_types_by_name['Form'] = _FORM
DESCRIPTOR.message_types_by_name['Registration'] = _REGISTRATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Form = _reflection.GeneratedProtocolMessageType('Form', (_message.Message,), {

  'Field' : _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {

    'Description' : _reflection.GeneratedProtocolMessageType('Description', (_message.Message,), {
      'DESCRIPTOR' : _FORM_FIELD_DESCRIPTION,
      '__module__' : 'eolymp.judge.form_pb2'
      # @@protoc_insertion_point(class_scope:eolymp.judge.Form.Field.Description)
      })
    ,
    'DESCRIPTOR' : _FORM_FIELD,
    '__module__' : 'eolymp.judge.form_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.Form.Field)
    })
  ,
  'DESCRIPTOR' : _FORM,
  '__module__' : 'eolymp.judge.form_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.Form)
  })
_sym_db.RegisterMessage(Form)
_sym_db.RegisterMessage(Form.Field)
_sym_db.RegisterMessage(Form.Field.Description)

Registration = _reflection.GeneratedProtocolMessageType('Registration', (_message.Message,), {

  'Data' : _reflection.GeneratedProtocolMessageType('Data', (_message.Message,), {
    'DESCRIPTOR' : _REGISTRATION_DATA,
    '__module__' : 'eolymp.judge.form_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.Registration.Data)
    })
  ,
  'DESCRIPTOR' : _REGISTRATION,
  '__module__' : 'eolymp.judge.form_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.Registration)
  })
_sym_db.RegisterMessage(Registration)
_sym_db.RegisterMessage(Registration.Data)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
